==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-panel/plugin-networkmonitor/networkmonitor_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Interface réseau &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Transmis %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Reçu %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>Go</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>To</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>Po</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Paramètres du moniteur réseau</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Généraux</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Moniteur</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Sans-Fil</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-panel/plugin-networkmonitor/networkmonitor_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Interface réseau &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Transmis %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Reçu %1</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>ko</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>Go</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>To</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>Po</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Paramètrage du moniteur réseau</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Moniteur</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Sans-Fil</translation>
    </message>
    <message>
        <location filename="../../../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
</context>
</TS>
